from fastapi import APIRouter, Depends, HTTPException, status
from sqlalchemy.orm import Session
from core.database import get_db
from schemas.user import UserLogin
from helpers.user_helpers import authenticate_user

router = APIRouter()

@router.post("/user-login", status_code=status.HTTP_200_OK, response_model=bool)
async def login_user(
    user_login: UserLogin,
    db: Session = Depends(get_db)
):
    """Authenticate user and log them in"""
    is_authenticated = authenticate_user(db=db, user_login=user_login)
    if not is_authenticated:
        raise HTTPException(status_code=status.HTTP_401_UNAUTHORIZED, detail="Invalid credentials")
    return is_authenticated